package immibis.core.api.util;

import immibis.core.api.APILocator;
import immibis.core.api.microblock.IMicroblockCoverSystem;
import immibis.core.api.microblock.IMicroblockSupporterTile;
import immibis.core.api.microblock.IMicroblockSystem;
import immibis.core.api.microblock.Part;
import net.minecraft.block.Block;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.world.World;

public final class MicroblockAPIUtils {
	/**
	 * Same as APILocator.getMicroblockSystem().getMicroblockContainerBlock() but returns null if there is no IMicroblockSystem.
	 */
	public static Block getMicroblockContainerBlock() {
		IMicroblockSystem ims = APILocator.getMicroblockSystem();
		if(ims == null)
			return null;
		else
			return ims.getMicroblockContainerBlock();
	}
	
	/**
	 * If there is a microblock container block at the specified coordinates, this function will save the parts in that block,
	 * place a new block, restore the parts, and return true.
	 * If there is not a microblock container block at the specified coordinates, or placing the block fails, it will
	 * return false.
	 */
	public static boolean mergeIntoMicroblockContainer(ItemStack itemstack, EntityPlayer entityplayer, World world, int i, int j, int k, int l, int blockID)
	{
		Block microblockContainerBlock = getMicroblockContainerBlock();
		if(microblockContainerBlock == null || world.getBlockId(i, j, k) != microblockContainerBlock.blockID)
			return false;

		IMicroblockSupporterTile tm = (IMicroblockSupporterTile)world.getBlockTileEntity(i, j, k);
		IMicroblockCoverSystem oldCI = tm.getCoverSystem();
		if(!world.setBlockWithNotify(i, j, k, blockID))
			return false;
		IMicroblockSupporterTile tcb = (IMicroblockSupporterTile)world.getBlockTileEntity(i, j, k);
		IMicroblockCoverSystem newCI = tcb.getCoverSystem();
		
		for(Part p : oldCI.getAllParts())
			newCI.addPart(p);
		Block b = Block.blocksList[blockID];
		
        b.onBlockPlacedBy(world, i, j, k, entityplayer);
		return true;
	}
}
